@@ -1,6 +1,8 @@
 
  library(fuzzyRankTests)
 
+ options(digits=5) # avoid rounding differences
+
  x <- c(-1.2, -0.7, -0.3, 0.1, 0.2, 0.3, 0.4, 0.9, 0.9, 1.0, 1.0,
      1.1, 1.5, 1.7, 1.9, 3.5, 5.1)
 
@@ -58,7 +60,10 @@
 
  fuzzy.sign.ci(x, alt = "great")
 
- fuzzy.sign.ci(x, alt = "great", conf = 0.5)
+ # as per request from Uwe Ligges (speaking for CRAN) comment this out
+ # because it gives a result that is hard to interpret
+ # on some computers but not on others (64 bit vs 32 bit)
+ # fuzzy.sign.ci(x, alt = "great", conf = 0.5)
 
  fuzzy.sign.ci(x, alt = "great", conf = 0.25)
 
