@@ -7,25 +7,25 @@
 
  fuzzy.signrank.test(x)
 
- wilcox.test(x)
+ wilcox.test(x, exact = FALSE)
 
  fuzzy.signrank.test(x, alt = "less")
 
- wilcox.test(x, alt = "less")
+ wilcox.test(x, alt = "less", exact = FALSE)
 
  fuzzy.signrank.test(x, alt = "great")
 
- wilcox.test(x, alt = "great")
+ wilcox.test(x, alt = "great", exact = FALSE)
 
  fuzzy.signrank.ci(x)
 
- wilcox.test(x, conf.int = TRUE)
+ wilcox.test(x, conf.int = TRUE, exact = FALSE)
 
  fuzzy.signrank.ci(x, alt = "less")
 
- wilcox.test(x, conf.int = TRUE, alt = "less")
+ wilcox.test(x, conf.int = TRUE, alt = "less", exact = FALSE)
 
  fuzzy.signrank.ci(x, alt = "great")
 
- wilcox.test(x, conf.int = TRUE, alt = "great")
+ wilcox.test(x, conf.int = TRUE, alt = "great", exact = FALSE)
 
